==> haskell-summoner-2.0.1.1-157-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 summoner
version:              2.0.1.1
visibility:           public
id:                   summoner-2.0.1.1-4gABahChVKD22ubogEo78o
key:                  summoner-2.0.1.1-4gABahChVKD22ubogEo78o
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            stable
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             CLI, CLI Tool, Development
abi:                  051dca32b9219897662ec5fecdf395a6
exposed:              True
exposed-modules:
    Summoner Summoner.CLI Summoner.Config Summoner.CustomPrelude
    Summoner.Decision Summoner.Default Summoner.GhcVer Summoner.License
    Summoner.Mode Summoner.Project Summoner.Question Summoner.Settings
    Summoner.Source Summoner.Template Summoner.Template.Cabal
    Summoner.Template.Doc Summoner.Template.GitHub
    Summoner.Template.Haskell Summoner.Template.Script
    Summoner.Template.Stack Summoner.Text Summoner.Tree

hidden-modules:       Paths_summoner
import-dirs:          /usr/lib/ghc-8.10.4/site-local/summoner-2.0.1.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/summoner-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/summoner-2.0.1.1
hs-libraries:         HSsummoner-2.0.1.1-4gABahChVKD22ubogEo78o
depends:
    base-4.14.1.0 relude-0.7.0.0-8EdoSnKv2rOD1gePLdzwm7
    aeson-1.5.6.0-4fHNEU34DqGLin6g6nejhx
    colourista-0.1.0.1-BkDzsAHpKwV6QmaJaBjb5c containers-0.6.2.1
    directory-1.3.6.0 filepath-1.4.2.1
    generic-data-0.9.2.0-28GrAbdgJQZ7Y8q40kKCQ6
    gitrev-1.3.1-Het0FatRKM8GuBdILU3orB
    neat-interpolation-0.5.1.2-2T2jNJoCbGb7Kj7bxybN8G
    optparse-applicative-0.16.1.0-Aums8NSUQ7MCCMQ1RSMBhb
    process-1.6.9.0 shellmet-0.0.4.0-33ubqRC2H21G9jUW5IilPw
    text-1.2.4.1 time-1.9.3 tomland-1.3.3.0-CJshzcGmbAtLoC8zIJJPcK
    validation-selective-0.1.0.1-DEsLYSdm2fHK6Z1Cs9slxs

haddock-interfaces:   /usr/share/doc/haskell-summoner/html/summoner.haddock
haddock-html:         /usr/share/doc/haskell-summoner/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-summoner-2.0.1.1-160-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 summoner
version:              2.0.1.1
visibility:           public
id:                   summoner-2.0.1.1-CJr1h5WaKfICP0hsywktPl
key:                  summoner-2.0.1.1-CJr1h5WaKfICP0hsywktPl
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            stable
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             CLI, CLI Tool, Development
abi:                  bba53acedfb5f6d95d036c4ed5cd6808
exposed:              True
exposed-modules:
    Summoner Summoner.CLI Summoner.Config Summoner.CustomPrelude
    Summoner.Decision Summoner.Default Summoner.GhcVer Summoner.License
    Summoner.Mode Summoner.Project Summoner.Question Summoner.Settings
    Summoner.Source Summoner.Template Summoner.Template.Cabal
    Summoner.Template.Doc Summoner.Template.GitHub
    Summoner.Template.Haskell Summoner.Template.Script
    Summoner.Template.Stack Summoner.Text Summoner.Tree

hidden-modules:       Paths_summoner
import-dirs:          /usr/lib/ghc-8.10.4/site-local/summoner-2.0.1.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/summoner-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/summoner-2.0.1.1
hs-libraries:         HSsummoner-2.0.1.1-CJr1h5WaKfICP0hsywktPl
depends:
    base-4.14.1.0 relude-0.7.0.0-FX6mxFybib84NYqSmb1TXi
    aeson-1.5.6.0-KKLnIH6l1ju5f1LsAaB2FK
    colourista-0.1.0.1-2ldNRVEUbmq50j2YkM6YZv containers-0.6.2.1
    directory-1.3.6.0 filepath-1.4.2.1
    generic-data-0.9.2.0-Cl986GpHa533VUVxI8iflQ
    gitrev-1.3.1-Het0FatRKM8GuBdILU3orB
    neat-interpolation-0.5.1.2-LvOMuYwD6cm6GO7EblrFTw
    optparse-applicative-0.16.1.0-S52gl7OfafHLRLHRkrUKV process-1.6.9.0
    shellmet-0.0.4.0-MA6BlP52os1nFxxTdWACH text-1.2.4.1 time-1.9.3
    tomland-1.3.3.0-5qKawrUtlzm3UJUAiUR9hs
    validation-selective-0.1.0.1-A2D3T4nkjrpHeb0XboBFrw

haddock-interfaces:   /usr/share/doc/haskell-summoner/html/summoner.haddock
haddock-html:         /usr/share/doc/haskell-summoner/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
